@@ -2,6 +2,7 @@
 
 from django_peeringdb.models import all_models
 
+
 def reftag_to_cls(fn):
     return fn
 
@@ -10,8 +11,11 @@ class Resource(object):
     def __init__(self, tag):
         self.tag = tag
 
+
 class Interface(object):
-    REFTAG_RESOURCE = dict([(model.HandleRef.tag, Resource(model.HandleRef.tag))
-                           for model in all_models])
+    REFTAG_RESOURCE = dict(
+        [(model.HandleRef.tag, Resource(model.HandleRef.tag)) for model in all_models]
+    )
+
     def get_resource(self, concrete):
         return self.REFTAG_RESOURCE[concrete.HandleRef.tag]
